@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen;
 
-our $DATE = '2014-08-04'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 
@@ -58,7 +58,7 @@ Perinci::Sub::Gen - Common stuffs used by Perinci::Sub::Gen::*
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Sub::Gen (from Perl distribution Perinci-Sub-Gen), released on 2014-08-04.
+This document describes version 0.03 of Perinci::Sub::Gen (from Perl distribution Perinci-Sub-Gen), released on 2015-09-04.
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Gen>.
 
 =head1 BUGS
 
@@ -83,11 +83,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
